***REPLICATION FILES FOR:
*"Political competition and rural welfare: evidence from Pakistan," by Katrina Kosec, Hamza Haider, David Spielman, and Fatima Zaidi (Oxford Economic Papers 2018)

*********NOTES**********
*1) This dofile is for students at a WIUT training source. Given time constraints, it replicates only results related to public goods and land (Table 1, HH-level regressions from Table 3, and Table 4). An expanded dofile replicating all results is available upon request and will also be published this year with the article.
*2) Place HHregs_share.dta in a folder along with this dofile. This file path needs to be entered below (line 21)
*3) Uncomment line 18 if you do not have ivreg2 installed (or type 'findit ivreg2' in the command line). 
*4) Latitude and longitude variables are "off-set" so that respondents are not identifiable. Therefore, results will not exactly match the results in the article.


clear
capture log close
set more off
set matsize 800
set memory 300m

*Un-comment out the below if you do not yet have ivreg2
*ssc install ivreg2

*Define file path - add path on your computer
capture cd "C:\Users\KKOSEC\Dropbox (IFPRI)\Central Asia\Summer School 2018\IV_OEP\Data_and_Output"

log using log_IV_WIUT, replace
use HHregs_share.dta, clear


********************************************************
****Create local macros to call on control variables****
********************************************************

#delimit;

local geographic 
latitude longitude lat_long lat_2 long_2 elevation ln_distance100k_meters
;

local villagecontrols 
dm_vill_electrified dm_vill_cylinder_gas dm_vill_natural_gas dm_vill_sewage_system 
pubtransport_to_city 
distance_commercial 
distance_postoffice
railway_station
distance_bhu distance_rhc distance_clinic_dispensary distance_midwife distance_hospital distance_lhv distance_hakeem
internal_roadFE2 internal_roadFE3 internal_roadFE4 internal_roadFE5 
external_roadFE2 external_roadFE3 external_roadFE4 external_roadFE5 
pct_ag_hhs
; 

local plotcontrols 
Q2_AREA_acre Q2_AREA_acre_sq 
soil_typeFE2 soil_typeFE3 soil_typeFE4 soil_typeFE5 
soil_fertilityFE1 soil_fertilityFE2 soil_fertilityFE3 
erosionFE2 erosionFE3 
slopeFE2 slopeFE3 slopeFE4 
dm_tubewell 
dm_waterlog dm_salinity 
dm_plot_in_village
watercourse_locationFE2 watercourse_locationFE3 watercourse_locationFE4
kharif_avg_rainfall rabi_avg_rainfall
;

local socioeconomic1 
hh_head_educFE2 hh_head_educFE3 
ethnicityFE2 ethnicityFE3 ethnicityFE4 ethnicityFE5 ethnicityFE6 ethnicityFE7 ethnicityFE8 ethnicityFE9 
hhsizeFE2 hhsizeFE3 hhsizeFE4 hhsizeFE5 hhsizeFE6 hhsizeFE7 hhsizeFE8 hhsizeFE9 hhsizeFE10 hhsizeFE11
croppattern2 croppattern3 croppattern4 croppattern5 croppattern6
;

local socioeconomic2 
ln_wealth_thousands ln_pcexp
;

local landuse
croppattern2 croppattern3 croppattern4 croppattern5 croppattern6
;

local acres_watercourse
tot_acres_owned tot_acres_owned_sq someland_onwa 
;
#delimit cr



***********************************
****Create infrastructure index****
***********************************

gen non_mud_roads=(internal_roadFE1!=1)
replace non_mud_roads=. if internal_roadFE1==.
label var non_mud_roads "Dummy - main road surface is NOT mud (concrete, asphalt, or gravel)"
tab non_mud_roads internal_roadFE1

gen indvil_infra_index=(dmelectricity + dmflush + dm_vill_electrified + non_mud_roads + FGD_S2Q16A + FGD_S2Q25A + FGD_S2Q26A + dmpipeddrainage + dmwaterpiped)/9
label var indvil_infra_index "Infrastructure index (average of 9 infrastructure dummies--2 indiv-level"



****************************
****Create justice index****
****************************

foreach x in 1 3 4 5 6 7 8 {
egen meanE_5_1_`x'=mean(E_5_1_`x')
egen sdE_5_1_`x'=sd(E_5_1_`x')
gen E_5_1_`x'_norm= (E_5_1_`x' - meanE_5_1_`x')/ sdE_5_1_`x'
label var E_5_1_`x'_norm "Normalized version of E_5_1_`x' - mean 0, sd 1, larger = more Justice"
}

gen E_6_2_5_reverse= 4 if E_6_2_5==1
replace E_6_2_5_reverse= 3 if E_6_2_5==2
replace E_6_2_5_reverse= 2 if E_6_2_5==3
replace E_6_2_5_reverse= 1 if E_6_2_5==4
egen meanE_6_2_5_reverse=mean(E_6_2_5_reverse)
egen sdE_6_2_5_reverse=sd(E_6_2_5_reverse)
gen E_6_2_5_norm= (E_6_2_5_reverse - meanE_6_2_5_reverse)/ sdE_6_2_5_reverse
label var E_6_2_5_norm "Normalized version of E_6_2_5 - mean 0, sd 1, larger = greater sense of justice"

gen justice=(E_5_1_1_norm + E_5_1_4_norm + E_5_1_5_norm + E_5_1_6_norm + E_5_1_7_norm + E_5_1_8_norm + E_6_2_5_norm)/7
label var justice "Justice score (uses all 7 questions)"



*****************************
****Create security index****
*****************************

foreach x in 20 21 22 {
egen meanE_5_1_`x'=mean(E_5_1_`x')
egen sdE_5_1_`x'=sd(E_5_1_`x')
gen E_5_1_`x'_norm= (E_5_1_`x' - meanE_5_1_`x')/ sdE_5_1_`x'
label var E_5_1_`x'_norm "Normalized version of E_5_1_`x' - mean 0, sd 1, larger = higher sense of security"
}

foreach x in 2 12 13 14 15 16 17 {
gen E_5_1_`x'_reverse= 4 if E_5_1_`x'==1
replace E_5_1_`x'_reverse= 3 if E_5_1_`x'==2
replace E_5_1_`x'_reverse= 2 if E_5_1_`x'==3
replace E_5_1_`x'_reverse= 1 if E_5_1_`x'==4
egen meanE_5_1_`x'_reverse=mean(E_5_1_`x'_reverse)
egen sdE_5_1_`x'_reverse=sd(E_5_1_`x'_reverse)
gen E_5_1_`x'_norm= (E_5_1_`x'_reverse - meanE_5_1_`x'_reverse)/ sdE_5_1_`x'_reverse
label var E_5_1_`x'_norm "Normalized version of E_5_1_`x' - mean 0, sd 1, larger = greater sense of security"
}

forvalues x=7/9 {
gen E_6_2_`x'_reverse= 4 if E_6_2_`x'==1
replace E_6_2_`x'_reverse= 3 if E_6_2_`x'==2
replace E_6_2_`x'_reverse= 2 if E_6_2_`x'==3
replace E_6_2_`x'_reverse= 1 if E_6_2_`x'==4
egen meanE_6_2_`x'_reverse=mean(E_6_2_`x'_reverse)
egen sdE_6_2_`x'_reverse=sd(E_6_2_`x'_reverse)
gen E_6_2_`x'_norm= (E_6_2_`x'_reverse - meanE_6_2_`x'_reverse)/ sdE_6_2_`x'_reverse
label var E_6_2_`x'_norm "Normalized version of E_6_2_`x' - mean 0, sd 1, larger = greater sense of security"
}

egen meanE_6_2_10=mean(E_6_2_10)
egen sdE_6_2_10=sd(E_6_2_10)
gen E_6_2_10_norm= (E_6_2_10 - meanE_6_2_10)/ sdE_6_2_10
label var E_6_2_10_norm "Normalized version of E_6_2_10 - mean 0, sd 1, larger = higher sense of security"

gen security=(E_5_1_2_norm + E_5_1_12_norm + E_5_1_13_norm + E_5_1_14_norm + E_5_1_15_norm + E_5_1_16_norm + E_5_1_17_norm + E_5_1_20_norm + E_5_1_21_norm + E_5_1_22_norm + E_6_2_9_norm  + E_6_2_10_norm)/12
label var security "sense of security score (uses all 14 questions)"

save HHregs_with_indices.dta, replace
clear



**************************
****SUMMARY STATISTICS****
**************************

*TABLE 1: HH-level regressions summary statistics 

#delimit ;

use HHregs_with_indices.dta, clear;

summ
justice indvil_infra_index security 
dmlandowner dm_rentsharedout share_ownedland_rentshr
pcexp pcexp_above_mean nonland_wealth total_landwealth_above_mean gini_land_wealth nonlandwealth_above_mean gini_nonland_wealth
pol_comp_PA vote_share_winner vote_margin_winner hhi_instr1 
latitude longitude lat_long lat_2 long_2 elevation ln_distance100k_meters 
hh_head_educFE1 hh_head_educFE2 hh_head_educFE3 hhsize ln_wealth_thousands ln_pcexp
tot_acres_owned tot_acres_owned_sq someland_onwa 
croppattern1 croppattern2 croppattern3 croppattern4 croppattern5 croppattern6;

#delimit cr



*******************
****REGRESSIONS****
*******************

*TABLE 3

capture erase "Table3.xls"
capture erase "Table3.txt"

use HHregs_with_indices.dta, clear

reg pol_comp_PA hhi_instr1 `geographic' `acres_watercourse' `socioeconomic1' `socioeconomic2' i.district if indvil_infra_index!=., vce(cluster pa2008)
outreg2 using "Table3.xls", append bdec(3) se label excel ctitle(IV 1st stage,`x') title (HH Level Regression)
test hhi_instr1

reg pol_comp_PA hhi_instr1 `geographic' `acres_watercourse' `socioeconomic1' `socioeconomic2' i.district if justice!=., vce(cluster pa2008)
outreg2 using "Table3.xls", append bdec(3) se label excel ctitle(IV 1st stage,`x') title (HH Level Regression)
test hhi_instr1

reg pol_comp_PA hhi_instr1 `geographic' `acres_watercourse' `socioeconomic1' `socioeconomic2' i.district if security!=., vce(cluster pa2008)
outreg2 using "Table3.xls", append bdec(3) se label excel ctitle(IV 1st stage,`x') title (HH Level Regression)
test hhi_instr1



*TABLE 4

capture erase "Table4.xls"
capture erase "Table4.txt"

use HHregs_with_indices.dta, clear

*OLS
foreach x of varlist justice indvil_infra_index security {
reg `x' pol_comp_PA `geographic' i.district, vce(cluster pa2008)
outreg2 using "Table4.xls", append bdec(3) se label excel ctitle(OLS,`x') title (HH Level Regression)
reg `x' pol_comp_PA `geographic' `acres_watercourse' `socioeconomic1' `socioeconomic2' i.district, vce(cluster pa2008)
outreg2 using "Table4.xls", append bdec(3) se label excel ctitle(OLS,`x') title (HH Level Regression)
}

*Use instrument directly
foreach x of varlist justice indvil_infra_index security {
reg `x' hhi_instr1 `geographic' i.district, vce(cluster pa2008)
outreg2 using "Table4.xls", append bdec(3) se label excel ctitle(OLS,`x') title (HH Level Regression)
reg `x' hhi_instr1 `geographic' `acres_watercourse' `socioeconomic1' `socioeconomic2' i.district, vce(cluster pa2008)
outreg2 using "Table4.xls", append bdec(3) se label excel ctitle(OLS,`x') title (HH Level Regression)
}

*IV
foreach x of varlist justice indvil_infra_index security {
ivreg2 `x' (pol_comp_PA = hhi_instr1) `geographic' i.district, robust cluster (pa2008) endogtest(pol_comp_PA)
outreg2 using "Table4.xls", append bdec(3) se label excel ctitle(IV,`x') title (HH Level Regression)
ivreg2 `x' (pol_comp_PA = hhi_instr1) `geographic' `acres_watercourse' `socioeconomic1' `socioeconomic2' i.district, robust cluster (pa2008) endogtest(pol_comp_PA)
outreg2 using "Table4.xls", append bdec(3) se label excel ctitle(IV,`x') title (HH Level Regression)
}

*DWH test
foreach x of varlist justice indvil_infra_index security {
ivreg2 `x' (pol_comp_PA = hhi_instr1) `geographic' `acres_watercourse' `socioeconomic1' `socioeconomic2' i.district, robust endogtest(pol_comp_PA)
}
